@@ -367,6 +367,10 @@ void BtBookshelfTreeModel::resetData() {
 
 void BtBookshelfTreeModel::addModule(CSwordModuleInfo *module, bool checked) {
     if (m_modules.contains(module)) return;
+
+#if QT_VERSION >= 0x040600
+    beginResetModel();
+#endif
     Grouping g(m_groupingOrder);
     addModule(module, QModelIndex(), g, checked);
 
@@ -376,7 +380,12 @@ void BtBookshelfTreeModel::addModule(CSwordModuleInfo *module, bool checked) {
            new modules. As a side effect, all attached views will also reset
            themselves.
     */
+
+#if QT_VERSION >= 0x040600
+    endResetModel();
+#else
     reset();
+#endif
 }
 
 void BtBookshelfTreeModel::addModule(CSwordModuleInfo *module,
